# basky

![Downloads](https://pypip.in/d/django-basky/badge.png) 
![](https://obscure-misc.s3.amazonaws.com/spacer.png) 
![version](https://pypip.in/v/django-basky/badge.png) 
![](https://obscure-misc.s3.amazonaws.com/spacer.png) 
![Build Status](https://jenkins.curle.io/buildStatus/icon?job=django-basky-test-django-1.5.5)
![](https://obscure-misc.s3.amazonaws.com/spacer.png) 
[![Coverage Status](https://coveralls.io/repos/jamiecurle/django-basky/badge.png?branch=develop)](https://coveralls.io/r/jamiecurle/django-basky?branch=develop)



A lightweight, robust basket app for your Django project.

Based on [django-ccbasket][0] but has been updated to work with Django 1.5.  The [basky documentation is online][1], but you may find parts that refer to ccbasket (basky's previous incarnation), like baskey it is a work in progress.



[0]: https://github.com/designcc/django-ccbasket
[1]: https://django-basky.readthedocs.org/en/latest/index.html

